# Roseau Load Flow

![CI](https://github.com/RoseauTechnologies/Roseau_Load_Flow/workflows/CI/badge.svg)
[![Documentation](https://github.com/RoseauTechnologies/Roseau_Load_Flow/actions/workflows/doc.yml/badge.svg)](https://github.com/RoseauTechnologies/Roseau_Load_Flow/actions/workflows/doc.yml)
[![pre-commit](https://github.com/RoseauTechnologies/Roseau_Load_Flow/actions/workflows/pre-commit.yml/badge.svg)](https://github.com/RoseauTechnologies/Roseau_Load_Flow/actions/workflows/pre-commit.yml)

_Roseau Load Flow_ is a highly capable three-phase load flow solver. This project is compatible with Python 3.9 and
above.

Please take a look at our documentation to see how to install and use `roseau-load-flow`.

- [Installation](https://roseautechnologies.github.io/Roseau_Load_Flow/Installation.html)
- [Usage](https://roseautechnologies.github.io/Roseau_Load_Flow/usage/index.html)

# Accessing the solver

This is the client library for the
[_Roseau Load Flow_](https://www.roseautechnologies.com/en/roseau-load-flow-en/) solver. To use the solver, you
need to sign up for an account. For inquiry, please contact us at contact@roseautechnologies.com.

If you are a **student or a teacher, free API credentials are provided**. Please contact us at
contact@roseautechnologies.com.

# Network data

With this library, there is a sample of 20 low-voltage and 20 medium-voltage feeders included for an easy
start! Each network is given with its summer and winter load point. At _Roseau Technologies_, we are able to provide
the major part of the French medium and low voltage networks. For more information, please contact us at
contact@roseautechnologies.com.

![Catalogue of networks](https://github.com/RoseauTechnologies/Roseau_Load_Flow/blob/main/doc/_static/Network/Catalogue.png?raw=True)

# Bug reports / Feature requests

If you find a bug or have a feature request, please open an issue on
[GitHub](https://github.com/RoseauTechnologies/Roseau_Load_Flow/issues)

# Credits

This software is developed by [Roseau Technologies](https://www.roseautechnologies.com/en).
[![Linkedin](https://i.stack.imgur.com/gVE0j.png) LinkedIn](https://www.linkedin.com/company/roseau-technologies/)
&nbsp;
[![GitHub](https://i.stack.imgur.com/tskMh.png) GitHub](https://github.com/RoseauTechnologies)
